# JupySQL

> **Note**
> This is a fork of [ipython-sql](https://github.com/catherinedevlin/ipython-sql), the objective is to turn this project into a full featured SQL client for Jupyter. We're looking for feedback and taking feature requests, so please [join our community](https://ploomber.io/community) and enter the #jupysql channel.

Run SQL in Jupyter/IPython via a `%sql` and `%%sql` magics.

## Installation

```
pip install jupysql
```

## Documentation

[Click here to see the documentation.](https://jupysql.readthedocs.io)
